metadata(version="0.3.2")

# Originally written by Paul Sokolovsky.

require("ffilib")

module("signal.py")
